@@ -211,12 +211,6 @@ class ClientTest(unittest.TestCase):
         stdin, stdout, stderr = self.tc.exec_command("yes")
         schan = self.ts.accept(1.0)
 
-        # Nobody else tests the API of exec_command so let's do it here for
-        # now. :weary:
-        assert isinstance(stdin, paramiko.ChannelFile)
-        assert isinstance(stdout, paramiko.ChannelFile)
-        assert isinstance(stderr, paramiko.ChannelStderrFile)
-
         schan.send("Hello there.\n")
         schan.send_stderr("This is on stderr.\n")
         schan.close()
@@ -377,13 +371,15 @@ class SSHClientTest(ClientTest):
         os.close(fd)
 
         client = paramiko.SSHClient()
-        assert len(client.get_host_keys()) == 0
+        self.assertEquals(0, len(client.get_host_keys()))
 
         host_id = "[%s]:%d" % (self.addr, self.port)
 
         client.get_host_keys().add(host_id, "ssh-rsa", public_host_key)
-        assert len(client.get_host_keys()) == 1
-        assert public_host_key == client.get_host_keys()[host_id]["ssh-rsa"]
+        self.assertEquals(1, len(client.get_host_keys()))
+        self.assertEquals(
+            public_host_key, client.get_host_keys()[host_id]["ssh-rsa"]
+        )
 
         client.save_host_keys(localname)
 
@@ -434,7 +430,7 @@ class SSHClientTest(ClientTest):
         with paramiko.SSHClient() as tc:
             self.tc = tc
             self.tc.set_missing_host_key_policy(paramiko.AutoAddPolicy())
-            assert len(self.tc.get_host_keys()) == 0
+            self.assertEquals(0, len(self.tc.get_host_keys()))
             self.tc.connect(**dict(self.connect_kwargs, password="pygmalion"))
 
             self.event.wait(1.0)
